Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Call ¶ added in v0.32.0
Call creates an API client, executes call, and decodes the response JSON into T.
func DecodeJSON ¶ added in v0.32.0
DecodeJSON reads the response body and unmarshals it directly into out.
func WrapServerErr ¶ added in v0.32.0
WrapServerErr decorates connection errors with a hint about STELLA_SERVER_URL.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.