types

package
v0.30.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 15, 2026 License: AGPL-3.0, AGPL-3.0-or-later Imports: 1 Imported by: 0

Documentation

Overview

Package types provides primitives to interact with the openapi HTTP API.

Code generated by github.com/oapi-codegen/oapi-codegen/v2 version v2.7.0 DO NOT EDIT.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Agent

type Agent struct {
	CreatorId    *int64         `json:"creator_id,omitempty"`
	Enabled      *bool          `json:"enabled,omitempty"`
	Id           *string        `json:"id,omitempty"`
	Model        *string        `json:"model,omitempty"`
	ModelFast    *string        `json:"model_fast,omitempty"`
	ModelStrong  *string        `json:"model_strong,omitempty"`
	Name         *string        `json:"name,omitempty"`
	Sandbox      *SandboxConfig `json:"sandbox,omitempty"`
	Scope        *string        `json:"scope,omitempty"`
	Soul         *string        `json:"soul,omitempty"`
	SystemPrompt *string        `json:"system_prompt,omitempty"`
	Workspace    *string        `json:"workspace,omitempty"`
}

Agent defines model for Agent.

type AgentList

type AgentList struct {
	Items []Agent `json:"items"`
}

AgentList defines model for AgentList.

type AgentTask added in v0.30.0

type AgentTask struct {
	AgentId *string `json:"agent_id,omitempty"`

	// Context Task-level metadata checkpoint (phase, decisions, blockers)
	Context   *map[string]interface{} `json:"context,omitempty"`
	CreatedAt time.Time               `json:"created_at"`

	// Deps IDs of tasks that must be done before this task can run
	Deps        *[]string `json:"deps,omitempty"`
	Description *string   `json:"description,omitempty"`
	Id          string    `json:"id"`

	// NotifyAt When to next notify the user; null means no pending notification
	NotifyAt *time.Time        `json:"notify_at,omitempty"`
	Priority AgentTaskPriority `json:"priority"`

	// ReviewRequest Structured review request set by the task agent
	ReviewRequest *AgentTaskReviewRequest `json:"review_request,omitempty"`
	SessionId     *string                 `json:"session_id,omitempty"`
	Status        AgentTaskStatus         `json:"status"`
	Title         string                  `json:"title"`
	UpdatedAt     time.Time               `json:"updated_at"`
	UserId        *int64                  `json:"user_id,omitempty"`
}

AgentTask defines model for AgentTask.

type AgentTaskAction added in v0.30.0

type AgentTaskAction struct {
	// Message Optional message for respond/reject actions
	Message *string             `json:"message,omitempty"`
	Type    AgentTaskActionType `json:"type"`
}

AgentTaskAction An action taken on a task (approve/reject review, respond to block, cancel)

type AgentTaskActionType added in v0.30.0

type AgentTaskActionType string

AgentTaskActionType defines model for AgentTaskAction.Type.

const (
	Approve AgentTaskActionType = "approve"
	Cancel  AgentTaskActionType = "cancel"
	Reject  AgentTaskActionType = "reject"
	Respond AgentTaskActionType = "respond"
)

Defines values for AgentTaskActionType.

func (AgentTaskActionType) Valid added in v0.30.0

func (e AgentTaskActionType) Valid() bool

Valid indicates whether the value is a known member of the AgentTaskActionType enum.

type AgentTaskEvent added in v0.30.0

type AgentTaskEvent struct {
	CreatedAt time.Time               `json:"created_at"`
	Detail    *map[string]interface{} `json:"detail,omitempty"`
	EventType AgentTaskEventEventType `json:"event_type"`
	Id        string                  `json:"id"`
	TaskId    string                  `json:"task_id"`
}

AgentTaskEvent defines model for AgentTaskEvent.

type AgentTaskEventEventType added in v0.30.0

type AgentTaskEventEventType string

AgentTaskEventEventType defines model for AgentTaskEvent.EventType.

const (
	AgentTaskEventEventTypeBlocked         AgentTaskEventEventType = "blocked"
	AgentTaskEventEventTypeCancelled       AgentTaskEventEventType = "cancelled"
	AgentTaskEventEventTypeDone            AgentTaskEventEventType = "done"
	AgentTaskEventEventTypeFailed          AgentTaskEventEventType = "failed"
	AgentTaskEventEventTypeProgress        AgentTaskEventEventType = "progress"
	AgentTaskEventEventTypeReviewRequested AgentTaskEventEventType = "review_requested"
	AgentTaskEventEventTypeStarted         AgentTaskEventEventType = "started"
)

Defines values for AgentTaskEventEventType.

func (AgentTaskEventEventType) Valid added in v0.30.0

func (e AgentTaskEventEventType) Valid() bool

Valid indicates whether the value is a known member of the AgentTaskEventEventType enum.

type AgentTaskEventList added in v0.30.0

type AgentTaskEventList struct {
	Items []AgentTaskEvent `json:"items"`
}

AgentTaskEventList defines model for AgentTaskEventList.

type AgentTaskInput added in v0.30.0

type AgentTaskInput struct {
	AgentId *string `json:"agent_id,omitempty"`

	// Deps IDs of tasks that must be done before this task can run
	Deps        *[]string               `json:"deps,omitempty"`
	Description *string                 `json:"description,omitempty"`
	Priority    *AgentTaskInputPriority `json:"priority,omitempty"`
	Title       string                  `json:"title"`
}

AgentTaskInput Fields for creating an agent task

type AgentTaskInputPriority added in v0.30.0

type AgentTaskInputPriority string

AgentTaskInputPriority defines model for AgentTaskInput.Priority.

const (
	AgentTaskInputPriorityRoutine AgentTaskInputPriority = "routine"
	AgentTaskInputPriorityUrgent  AgentTaskInputPriority = "urgent"
)

Defines values for AgentTaskInputPriority.

func (AgentTaskInputPriority) Valid added in v0.30.0

func (e AgentTaskInputPriority) Valid() bool

Valid indicates whether the value is a known member of the AgentTaskInputPriority enum.

type AgentTaskList added in v0.30.0

type AgentTaskList struct {
	Items []AgentTask `json:"items"`
}

AgentTaskList defines model for AgentTaskList.

type AgentTaskPriority added in v0.30.0

type AgentTaskPriority string

AgentTaskPriority defines model for AgentTask.Priority.

const (
	AgentTaskPriorityRoutine AgentTaskPriority = "routine"
	AgentTaskPriorityUrgent  AgentTaskPriority = "urgent"
)

Defines values for AgentTaskPriority.

func (AgentTaskPriority) Valid added in v0.30.0

func (e AgentTaskPriority) Valid() bool

Valid indicates whether the value is a known member of the AgentTaskPriority enum.

type AgentTaskReviewRequest added in v0.30.0

type AgentTaskReviewRequest struct {
	Details        *string                     `json:"details,omitempty"`
	Options        *[]string                   `json:"options,omitempty"`
	Question       *string                     `json:"question,omitempty"`
	Recommendation *string                     `json:"recommendation,omitempty"`
	Risk           *AgentTaskReviewRequestRisk `json:"risk,omitempty"`
}

AgentTaskReviewRequest Structured review request set by the task agent

type AgentTaskReviewRequestRisk added in v0.30.0

type AgentTaskReviewRequestRisk string

AgentTaskReviewRequestRisk defines model for AgentTaskReviewRequest.Risk.

const (
	High   AgentTaskReviewRequestRisk = "high"
	Low    AgentTaskReviewRequestRisk = "low"
	Medium AgentTaskReviewRequestRisk = "medium"
)

Defines values for AgentTaskReviewRequestRisk.

func (AgentTaskReviewRequestRisk) Valid added in v0.30.0

func (e AgentTaskReviewRequestRisk) Valid() bool

Valid indicates whether the value is a known member of the AgentTaskReviewRequestRisk enum.

type AgentTaskStatus added in v0.30.0

type AgentTaskStatus string

AgentTaskStatus defines model for AgentTask.Status.

const (
	AgentTaskStatusBlocked         AgentTaskStatus = "blocked"
	AgentTaskStatusCancelled       AgentTaskStatus = "cancelled"
	AgentTaskStatusDone            AgentTaskStatus = "done"
	AgentTaskStatusFailed          AgentTaskStatus = "failed"
	AgentTaskStatusPending         AgentTaskStatus = "pending"
	AgentTaskStatusReviewRequested AgentTaskStatus = "review_requested"
	AgentTaskStatusRunning         AgentTaskStatus = "running"
)

Defines values for AgentTaskStatus.

func (AgentTaskStatus) Valid added in v0.30.0

func (e AgentTaskStatus) Valid() bool

Valid indicates whether the value is a known member of the AgentTaskStatus enum.

type AgentTaskUpdate added in v0.30.0

type AgentTaskUpdate struct {
	AgentId     *string                  `json:"agent_id,omitempty"`
	Description *string                  `json:"description,omitempty"`
	Priority    *AgentTaskUpdatePriority `json:"priority,omitempty"`
	Title       *string                  `json:"title,omitempty"`
}

AgentTaskUpdate Fields for updating an agent task (all optional)

type AgentTaskUpdatePriority added in v0.30.0

type AgentTaskUpdatePriority string

AgentTaskUpdatePriority defines model for AgentTaskUpdate.Priority.

const (
	Routine AgentTaskUpdatePriority = "routine"
	Urgent  AgentTaskUpdatePriority = "urgent"
)

Defines values for AgentTaskUpdatePriority.

func (AgentTaskUpdatePriority) Valid added in v0.30.0

func (e AgentTaskUpdatePriority) Valid() bool

Valid indicates whether the value is a known member of the AgentTaskUpdatePriority enum.

type AgentUser

type AgentUser struct {
	Id       *int64  `json:"id,omitempty"`
	Username *string `json:"username,omitempty"`
}

AgentUser defines model for AgentUser.

type AgentUserList

type AgentUserList struct {
	Items []AgentUser `json:"items"`
}

AgentUserList defines model for AgentUserList.

type Article

type Article struct {
	AgentId      *string `json:"agent_id,omitempty"`
	Author       *string `json:"author,omitempty"`
	CanonicalUrl string  `json:"canonical_url"`

	// Content Article body in markdown. Returned only when ?include=content is set.
	Content     *string            `json:"content,omitempty"`
	CreatedAt   time.Time          `json:"created_at"`
	FilePath    string             `json:"file_path"`
	Id          string             `json:"id"`
	Metadata    *map[string]string `json:"metadata,omitempty"`
	PublishedAt *time.Time         `json:"published_at,omitempty"`
	ReadAt      *time.Time         `json:"read_at,omitempty"`
	SavedAt     time.Time          `json:"saved_at"`
	SourceType  SourceType         `json:"source_type"`
	Starred     bool               `json:"starred"`
	Status      ArticleStatus      `json:"status"`
	Summary     *string            `json:"summary,omitempty"`
	Tags        *[]string          `json:"tags,omitempty"`
	Title       string             `json:"title"`
	UpdatedAt   time.Time          `json:"updated_at"`
	Url         string             `json:"url"`
}

Article defines model for Article.

type ArticleList

type ArticleList struct {
	Items []Article `json:"items"`
}

ArticleList defines model for ArticleList.

type ArticleStatus

type ArticleStatus string

ArticleStatus defines model for ArticleStatus.

const (
	Archived ArticleStatus = "archived"
	Read     ArticleStatus = "read"
	Unread   ArticleStatus = "unread"
)

Defines values for ArticleStatus.

func (ArticleStatus) Valid

func (e ArticleStatus) Valid() bool

Valid indicates whether the value is a known member of the ArticleStatus enum.

type AssignAgentUserRequest

type AssignAgentUserRequest struct {
	UserId int64 `json:"user_id"`
}

AssignAgentUserRequest defines model for AssignAgentUserRequest.

type AuthResponse

type AuthResponse struct {
	Id       int64  `json:"id"`
	Username string `json:"username"`
}

AuthResponse defines model for AuthResponse.

type AuthUser

type AuthUser struct {
	CreatedAt  string     `json:"created_at"`
	Id         int64      `json:"id"`
	Identities []Identity `json:"identities"`
	IsActive   bool       `json:"is_active"`
	Role       string     `json:"role"`
	UpdatedAt  string     `json:"updated_at"`
	Username   string     `json:"username"`
}

AuthUser defines model for AuthUser.

type AuthUserList

type AuthUserList struct {
	Items []AuthUser `json:"items"`
}

AuthUserList defines model for AuthUserList.

type BadRequest

type BadRequest struct {
	Error string `json:"error"`
}

BadRequest defines model for BadRequest.

type BuiltinResource

type BuiltinResource struct {
	Description *string                 `json:"description,omitempty"`
	Hash        *string                 `json:"hash,omitempty"`
	Id          string                  `json:"id"`
	Kind        string                  `json:"kind"`
	Metadata    *map[string]interface{} `json:"metadata,omitempty"`
	Name        string                  `json:"name"`
	Tags        *[]string               `json:"tags,omitempty"`
}

BuiltinResource defines model for BuiltinResource.

type BuiltinResourceDetail

type BuiltinResourceDetail struct {
	Content     string                  `json:"content"`
	Description *string                 `json:"description,omitempty"`
	Hash        *string                 `json:"hash,omitempty"`
	Id          string                  `json:"id"`
	Kind        string                  `json:"kind"`
	Metadata    *map[string]interface{} `json:"metadata,omitempty"`
	Name        string                  `json:"name"`
	Tags        *[]string               `json:"tags,omitempty"`
}

BuiltinResourceDetail defines model for BuiltinResourceDetail.

type CachedModel

type CachedModel struct {
	Model    string `json:"model"`
	Provider string `json:"provider"`
}

CachedModel defines model for CachedModel.

type ChangePasswordRequest

type ChangePasswordRequest struct {
	CurrentPassword string `json:"current_password"`
	NewPassword     string `json:"new_password"`
}

ChangePasswordRequest defines model for ChangePasswordRequest.

type Channel

type Channel struct {
	AgentId *string `json:"agent_id,omitempty"`

	// Config JSON string of the channel config
	Config  string `json:"config"`
	Enabled bool   `json:"enabled"`
	Id      string `json:"id"`
	Type    string `json:"type"`
}

Channel defines model for Channel.

type ChannelList

type ChannelList struct {
	Items []Channel `json:"items"`
}

ChannelList defines model for ChannelList.

type ChannelWriteRequest

type ChannelWriteRequest struct {
	AgentId *string `json:"agent_id,omitempty"`

	// Config JSON string of the channel config
	Config *string `json:"config,omitempty"`
	Id     *string `json:"id,omitempty"`
	Type   *string `json:"type,omitempty"`
}

ChannelWriteRequest defines model for ChannelWriteRequest.

type Conflict

type Conflict struct {
	Error string `json:"error"`
}

Conflict defines model for Conflict.

type CreateAgentRequest

type CreateAgentRequest struct {
	CreatorId    *int64         `json:"creator_id,omitempty"`
	Enabled      *bool          `json:"enabled,omitempty"`
	Id           *string        `json:"id,omitempty"`
	Model        *string        `json:"model,omitempty"`
	ModelFast    *string        `json:"model_fast,omitempty"`
	ModelStrong  *string        `json:"model_strong,omitempty"`
	Name         *string        `json:"name,omitempty"`
	Sandbox      *SandboxConfig `json:"sandbox,omitempty"`
	Scope        *string        `json:"scope,omitempty"`
	Soul         *string        `json:"soul,omitempty"`
	SystemPrompt *string        `json:"system_prompt,omitempty"`
	TemplateId   *string        `json:"template_id,omitempty"`
	Workspace    *string        `json:"workspace,omitempty"`
}

CreateAgentRequest defines model for CreateAgentRequest.

type CreateFeedRequest

type CreateFeedRequest struct {
	AgentId *string `json:"agent_id,omitempty"`

	// Title Optional override; server fetches feed metadata if omitted
	Title *string `json:"title,omitempty"`
	Url   string  `json:"url"`
}

CreateFeedRequest defines model for CreateFeedRequest.

type CreateSessionRequest

type CreateSessionRequest struct {
	AgentId *string `json:"agent_id,omitempty"`
}

CreateSessionRequest defines model for CreateSessionRequest.

type CreateSkillRequest

type CreateSkillRequest struct {
	AgentId                *string            `json:"agent_id,omitempty"`
	Description            *string            `json:"description,omitempty"`
	DisableModelInvocation *bool              `json:"disable_model_invocation,omitempty"`
	Files                  *map[string]string `json:"files,omitempty"`
	Name                   *string            `json:"name,omitempty"`
	Scope                  *string            `json:"scope,omitempty"`
	Status                 *string            `json:"status,omitempty"`
	UserId                 *int64             `json:"user_id,omitempty"`
}

CreateSkillRequest defines model for CreateSkillRequest.

type DeleteFileResult

type DeleteFileResult struct {
	Path *string `json:"path,omitempty"`
}

DeleteFileResult defines model for DeleteFileResult.

type DeleteResult

type DeleteResult struct {
	Status string `json:"status"`
}

DeleteResult defines model for DeleteResult.

type Digest

type Digest struct {
	ArchivedCount        int64      `json:"archived_count"`
	Date                 time.Time  `json:"date"`
	ReadCount            int64      `json:"read_count"`
	SavedYesterday       []Article  `json:"saved_yesterday"`
	SavedYesterdayCount  int        `json:"saved_yesterday_count"`
	StarredCount         int64      `json:"starred_count"`
	TopTags              []TagCount `json:"top_tags"`
	TotalArticles        int64      `json:"total_articles"`
	UnreadCount          int64      `json:"unread_count"`
	WorthRevisiting      []Article  `json:"worth_revisiting"`
	WorthRevisitingCount int        `json:"worth_revisiting_count"`
}

Digest defines model for Digest.

type DuplicateSkillResult

type DuplicateSkillResult struct {
	Id   *string `json:"id,omitempty"`
	Name *string `json:"name,omitempty"`
}

DuplicateSkillResult defines model for DuplicateSkillResult.

type Error

type Error struct {
	Error string `json:"error"`
}

Error defines model for Error.

type Feed

type Feed struct {
	AgentId       *string    `json:"agent_id,omitempty"`
	CheckInterval string     `json:"check_interval"`
	CreatedAt     time.Time  `json:"created_at"`
	Description   *string    `json:"description,omitempty"`
	Enabled       bool       `json:"enabled"`
	Id            string     `json:"id"`
	LastCheckedAt *time.Time `json:"last_checked_at,omitempty"`
	LastEtag      *string    `json:"last_etag,omitempty"`
	LastModified  *string    `json:"last_modified,omitempty"`
	Title         string     `json:"title"`
	UpdatedAt     time.Time  `json:"updated_at"`
	Url           string     `json:"url"`
}

Feed defines model for Feed.

type FeedEntry

type FeedEntry struct {
	ArticleId    *string         `json:"article_id,omitempty"`
	Attempts     int             `json:"attempts"`
	DiscoveredAt time.Time       `json:"discovered_at"`
	ErrorMsg     *string         `json:"error_msg,omitempty"`
	FeedId       string          `json:"feed_id"`
	Guid         string          `json:"guid"`
	Id           string          `json:"id"`
	ProcessedAt  *time.Time      `json:"processed_at,omitempty"`
	Status       FeedEntryStatus `json:"status"`
	Title        string          `json:"title"`
	Url          string          `json:"url"`
}

FeedEntry defines model for FeedEntry.

type FeedEntryList

type FeedEntryList struct {
	Items []FeedEntry `json:"items"`
}

FeedEntryList defines model for FeedEntryList.

type FeedEntryStatus

type FeedEntryStatus string

FeedEntryStatus defines model for FeedEntryStatus.

const (
	FeedEntryStatusError   FeedEntryStatus = "error"
	FeedEntryStatusPending FeedEntryStatus = "pending"
	FeedEntryStatusSaved   FeedEntryStatus = "saved"
	FeedEntryStatusSkipped FeedEntryStatus = "skipped"
)

Defines values for FeedEntryStatus.

func (FeedEntryStatus) Valid

func (e FeedEntryStatus) Valid() bool

Valid indicates whether the value is a known member of the FeedEntryStatus enum.

type FeedList

type FeedList struct {
	Items []Feed `json:"items"`
}

FeedList defines model for FeedList.

type FeedPollResult

type FeedPollResult struct {
	// Error Set if the upstream RSS fetch failed but the feed exists
	Error      *string     `json:"error,omitempty"`
	Feed       Feed        `json:"feed"`
	NewEntries []FeedEntry `json:"new_entries"`
}

FeedPollResult defines model for FeedPollResult.

type FetchModelsRequest

type FetchModelsRequest struct {
	ApiKey  *string `json:"api_key,omitempty"`
	BaseUrl *string `json:"base_url,omitempty"`
}

FetchModelsRequest defines model for FetchModelsRequest.

type Forbidden

type Forbidden struct {
	Error string `json:"error"`
}

Forbidden defines model for Forbidden.

type GenerateLinkCodeRequest

type GenerateLinkCodeRequest struct {
	Platform string `json:"platform"`
}

GenerateLinkCodeRequest defines model for GenerateLinkCodeRequest.

type GlobalInstallSkillRequest

type GlobalInstallSkillRequest struct {
	AgentId *string `json:"agent_id,omitempty"`
	Scope   *string `json:"scope,omitempty"`
	Source  string  `json:"source"`
	UserId  *int64  `json:"user_id,omitempty"`
}

GlobalInstallSkillRequest defines model for GlobalInstallSkillRequest.

type Identity

type Identity struct {
	ExternalId string    `json:"external_id"`
	Id         int64     `json:"id"`
	LinkedAt   time.Time `json:"linked_at"`
	Name       string    `json:"name"`
	Platform   string    `json:"platform"`
	UserId     int64     `json:"user_id"`
}

Identity defines model for Identity.

type InstallSkillRequest

type InstallSkillRequest struct {
	Source string `json:"source"`
}

InstallSkillRequest defines model for InstallSkillRequest.

type Job

type Job struct {
	AgentId *string `json:"agent_id,omitempty"`

	// At RFC3339 one-time timestamp (mutually exclusive with cron/every)
	At        *string    `json:"at,omitempty"`
	CreatedAt *time.Time `json:"created_at,omitempty"`

	// Cron Cron expression (mutually exclusive with every/at)
	Cron        *string `json:"cron,omitempty"`
	Description *string `json:"description,omitempty"`
	Enabled     bool    `json:"enabled"`

	// Every Go duration string, e.g. '30m' (mutually exclusive with cron/at)
	Every     *string    `json:"every,omitempty"`
	Id        string     `json:"id"`
	JobKey    *string    `json:"job_key,omitempty"`
	LastError *string    `json:"last_error,omitempty"`
	LastRunAt *time.Time `json:"last_run_at,omitempty"`

	// Message Prompt/instruction to run on schedule
	Message string `json:"message"`
	Name    string `json:"name"`

	// OwnerKind Ownership class: 'user' or 'plugin'
	OwnerKind *string `json:"owner_kind,omitempty"`

	// Payload Arbitrary structured data for plugin-owned jobs
	Payload     *map[string]interface{} `json:"payload,omitempty"`
	PluginId    *string                 `json:"plugin_id,omitempty"`
	RuntimeName *string                 `json:"runtime_name,omitempty"`

	// SessionMode Session behaviour: 'reuse' or 'new'
	SessionMode string     `json:"session_mode"`
	UpdatedAt   *time.Time `json:"updated_at,omitempty"`
	UserId      *int64     `json:"user_id,omitempty"`
}

Job defines model for Job.

type JobInput

type JobInput struct {
	AgentId     *string `json:"agent_id,omitempty"`
	At          *string `json:"at,omitempty"`
	Cron        *string `json:"cron,omitempty"`
	Description *string `json:"description,omitempty"`
	Enabled     *bool   `json:"enabled,omitempty"`
	Every       *string `json:"every,omitempty"`
	Message     *string `json:"message,omitempty"`
	Name        *string `json:"name,omitempty"`
	SessionMode *string `json:"session_mode,omitempty"`

	// UserId Admin-only: set 0 for system jobs
	UserId *int64 `json:"user_id,omitempty"`
}

JobInput Fields for creating or updating a job. For create: name, message, and exactly one of cron/every/at are required.

type JobList

type JobList struct {
	Items []Job `json:"items"`
}

JobList defines model for JobList.

type JobRun

type JobRun struct {
	Duration   *string `json:"duration,omitempty"`
	Error      *string `json:"error,omitempty"`
	FinishedAt *string `json:"finished_at,omitempty"`
	Id         string  `json:"id"`
	JobId      string  `json:"job_id"`
	SessionId  string  `json:"session_id"`
	StartedAt  string  `json:"started_at"`
	Status     string  `json:"status"`
	UserId     *int64  `json:"user_id,omitempty"`
}

JobRun defines model for JobRun.

type JobRunList

type JobRunList = []JobRun

JobRunList defines model for JobRunList.

type LinkCodeResponse

type LinkCodeResponse struct {
	Code     string `json:"code"`
	Platform string `json:"platform"`
}

LinkCodeResponse defines model for LinkCodeResponse.

type LoginRequest

type LoginRequest struct {
	Password string `json:"password"`
	Username string `json:"username"`
}

LoginRequest defines model for LoginRequest.

type ManifestOAuthProvider added in v0.27.0

type ManifestOAuthProvider struct {
	ClientId *string   `json:"client_id,omitempty"`
	Id       *string   `json:"id,omitempty"`
	Scopes   *[]string `json:"scopes,omitempty"`
	VaultKey *string   `json:"vault_key,omitempty"`
}

ManifestOAuthProvider defines model for ManifestOAuthProvider.

type ManifestPlugin

type ManifestPlugin map[string]interface{}

ManifestPlugin defines model for ManifestPlugin.

type ManifestPluginsResponse added in v0.27.0

type ManifestPluginsResponse struct {
	OauthProviders *[]ManifestOAuthProvider `json:"oauth_providers,omitempty"`
	Plugins        *[]ManifestPlugin        `json:"plugins,omitempty"`
}

ManifestPluginsResponse defines model for ManifestPluginsResponse.

type MeResponse

type MeResponse struct {
	Id       int64  `json:"id"`
	IsAdmin  bool   `json:"is_admin"`
	Role     string `json:"role"`
	Username string `json:"username"`
}

MeResponse defines model for MeResponse.

type NotFound

type NotFound struct {
	Error string `json:"error"`
}

NotFound defines model for NotFound.

type OAuthConnectedResponse

type OAuthConnectedResponse struct {
	Connected bool    `json:"connected"`
	Username  *string `json:"username,omitempty"`
}

OAuthConnectedResponse defines model for OAuthConnectedResponse.

type OAuthFlowStatus

type OAuthFlowStatus struct {
	ExpiresAt       string  `json:"expires_at"`
	FlowId          string  `json:"flow_id"`
	Provider        string  `json:"provider"`
	State           string  `json:"state"`
	UserCode        *string `json:"user_code,omitempty"`
	VerificationUri string  `json:"verification_uri"`
}

OAuthFlowStatus defines model for OAuthFlowStatus.

type OAuthProviderConfig added in v0.27.0

type OAuthProviderConfig struct {
	ClientId     string  `json:"client_id"`
	ClientSecret string  `json:"client_secret"`
	ProviderId   string  `json:"provider_id"`
	RedirectUrl  *string `json:"redirect_url,omitempty"`
}

OAuthProviderConfig defines model for OAuthProviderConfig.

type OAuthProviderConfigInput added in v0.27.0

type OAuthProviderConfigInput struct {
	ClientId     string  `json:"client_id"`
	ClientSecret string  `json:"client_secret"`
	RedirectUrl  *string `json:"redirect_url,omitempty"`
}

OAuthProviderConfigInput defines model for OAuthProviderConfigInput.

type OAuthProviderStatus

type OAuthProviderStatus struct {
	Available   bool    `json:"available"`
	Configured  bool    `json:"configured"`
	Connected   bool    `json:"connected"`
	Provider    string  `json:"provider"`
	Unavailable *string `json:"unavailable,omitempty"`
	Username    *string `json:"username,omitempty"`
}

OAuthProviderStatus defines model for OAuthProviderStatus.

type PluginView

type PluginView struct {
	AdminVisible *bool                   `json:"admin_visible,omitempty"`
	Capabilities *[]string               `json:"capabilities,omitempty"`
	Config       *map[string]interface{} `json:"config,omitempty"`
	Description  *string                 `json:"description,omitempty"`
	DisplayName  *string                 `json:"display_name,omitempty"`
	Enabled      *bool                   `json:"enabled,omitempty"`
	HasConfig    *bool                   `json:"has_config,omitempty"`
	HasStatus    *bool                   `json:"has_status,omitempty"`
	Id           *string                 `json:"id,omitempty"`
	Kind         *string                 `json:"kind,omitempty"`
	Managed      *bool                   `json:"managed,omitempty"`
	Name         *string                 `json:"name,omitempty"`
	Persisted    *bool                   `json:"persisted,omitempty"`
	PersistedId  *string                 `json:"persisted_id,omitempty"`
}

PluginView defines model for PluginView.

type ProfileInstallSkillRequest

type ProfileInstallSkillRequest struct {
	Source string `json:"source"`
}

ProfileInstallSkillRequest defines model for ProfileInstallSkillRequest.

type Provider

type Provider struct {
	ApiKey  string                    `json:"api_key"`
	BaseUrl string                    `json:"base_url"`
	Enabled bool                      `json:"enabled"`
	Id      string                    `json:"id"`
	Models  *map[string]ProviderModel `json:"models,omitempty"`
	Name    string                    `json:"name"`
	Type    string                    `json:"type"`
}

Provider defines model for Provider.

type ProviderModel

type ProviderModel struct {
	ContextWindow *int               `json:"contextWindow,omitempty"`
	Cost          *ProviderModelCost `json:"cost,omitempty"`
	Enabled       bool               `json:"enabled"`
	Id            *string            `json:"id,omitempty"`
	Input         *[]string          `json:"input,omitempty"`
	MaxTokens     *int               `json:"maxTokens,omitempty"`
	Name          *string            `json:"name,omitempty"`
	Output        *[]string          `json:"output,omitempty"`
	Reasoning     *bool              `json:"reasoning,omitempty"`
}

ProviderModel defines model for ProviderModel.

type ProviderModelCost

type ProviderModelCost struct {
	CacheRead  *float64 `json:"cacheRead,omitempty"`
	CacheWrite *float64 `json:"cacheWrite,omitempty"`
	Input      *float64 `json:"input,omitempty"`
	Output     *float64 `json:"output,omitempty"`
}

ProviderModelCost defines model for ProviderModelCost.

type ProviderModelItem

type ProviderModelItem struct {
	Config  *ProviderModel `json:"config,omitempty"`
	Enabled bool           `json:"enabled"`
	Id      string         `json:"id"`
	Name    *string        `json:"name,omitempty"`
	Source  string         `json:"source"`
}

ProviderModelItem defines model for ProviderModelItem.

type ProviderType

type ProviderType struct {
	DefaultUrl string `json:"default_url"`
	Id         string `json:"id"`
	Name       string `json:"name"`
}

ProviderType defines model for ProviderType.

type PublicChannel

type PublicChannel struct {
	AgentId   *string `json:"agent_id,omitempty"`
	AgentName *string `json:"agent_name,omitempty"`
	Enabled   bool    `json:"enabled"`
	Id        string  `json:"id"`
	Label     string  `json:"label"`
	Type      string  `json:"type"`
}

PublicChannel defines model for PublicChannel.

type PublicChannelList

type PublicChannelList struct {
	Items []PublicChannel `json:"items"`
}

PublicChannelList defines model for PublicChannelList.

type RegisterRequest

type RegisterRequest struct {
	Password string `json:"password"`
	Username string `json:"username"`
}

RegisterRequest defines model for RegisterRequest.

type SandboxConfig

type SandboxConfig struct {
	Network *SandboxNetworkConfig `json:"network,omitempty"`
}

SandboxConfig defines model for SandboxConfig.

type SandboxNetworkConfig

type SandboxNetworkConfig struct {
	Allowlist *[]string `json:"allowlist,omitempty"`
	Mode      *string   `json:"mode,omitempty"`
}

SandboxNetworkConfig defines model for SandboxNetworkConfig.

type SaveArticleRequest

type SaveArticleRequest struct {
	AgentId      *string `json:"agent_id,omitempty"`
	Author       *string `json:"author,omitempty"`
	CanonicalUrl *string `json:"canonical_url,omitempty"`

	// Content Markdown body. If empty and the article exists, only metadata is updated; if empty and the article is new, the request fails 400.
	Content     *string            `json:"content,omitempty"`
	Metadata    *map[string]string `json:"metadata,omitempty"`
	PublishedAt *time.Time         `json:"published_at,omitempty"`
	SourceType  *SourceType        `json:"source_type,omitempty"`
	Summary     *string            `json:"summary,omitempty"`
	Tags        *[]string          `json:"tags,omitempty"`
	Title       *string            `json:"title,omitempty"`
	Url         string             `json:"url"`
}

SaveArticleRequest defines model for SaveArticleRequest.

type SaveDigestRequest added in v0.30.0

type SaveDigestRequest struct {
	// Date YYYY-MM-DD; defaults to today if omitted
	Date      *string `json:"date,omitempty"`
	Narrative string  `json:"narrative"`
}

SaveDigestRequest defines model for SaveDigestRequest.

type SendMessageRequest

type SendMessageRequest struct {
	// Content Message content (required)
	Content string `json:"content"`
}

SendMessageRequest defines model for SendMessageRequest.

type Session

type Session struct {
	AgentId    string `json:"agent_id"`
	Archived   bool   `json:"archived"`
	Channel    string `json:"channel"`
	CreatedAt  string `json:"created_at"`
	Id         string `json:"id"`
	LastActive string `json:"last_active"`
	Title      string `json:"title"`
	UserId     int64  `json:"user_id"`
}

Session defines model for Session.

type SessionDetail

type SessionDetail struct {
	AgentId    string  `json:"agent_id"`
	AgentName  *string `json:"agent_name,omitempty"`
	Archived   bool    `json:"archived"`
	Channel    string  `json:"channel"`
	CreatedAt  string  `json:"created_at"`
	Id         string  `json:"id"`
	LastActive string  `json:"last_active"`
	Title      string  `json:"title"`
	UserId     int64   `json:"user_id"`
	UserName   *string `json:"user_name,omitempty"`
}

SessionDetail defines model for SessionDetail.

type SessionWorkspace

type SessionWorkspace struct {
	// Paths Relative file and directory paths within the workspace. Directory paths end with a slash.
	Paths []string `json:"paths"`

	// Root Absolute path of the workspace root directory
	Root string `json:"root"`

	// TotalBytes Total size of regular files in bytes
	TotalBytes int64 `json:"total_bytes"`

	// TotalDirs Number of directories in the workspace, excluding the root
	TotalDirs int `json:"total_dirs"`

	// TotalFiles Number of files in the workspace
	TotalFiles int `json:"total_files"`
}

SessionWorkspace defines model for SessionWorkspace.

type SetMemoryRequest

type SetMemoryRequest struct {
	Content string `json:"content"`
}

SetMemoryRequest defines model for SetMemoryRequest.

type SetSoulRequest

type SetSoulRequest struct {
	Soul string `json:"soul"`
}

SetSoulRequest defines model for SetSoulRequest.

type SetVaultEntryRequest

type SetVaultEntryRequest struct {
	Value string `json:"value"`
}

SetVaultEntryRequest defines model for SetVaultEntryRequest.

type Skill

type Skill struct {
	AgentId                *string   `json:"agent_id,omitempty"`
	CreatedAt              *string   `json:"created_at,omitempty"`
	Description            *string   `json:"description,omitempty"`
	DisableModelInvocation *bool     `json:"disable_model_invocation,omitempty"`
	Files                  *[]string `json:"files,omitempty"`
	Id                     *string   `json:"id,omitempty"`
	Name                   *string   `json:"name,omitempty"`
	Scope                  *string   `json:"scope,omitempty"`
	Status                 *string   `json:"status,omitempty"`
	UpdatedAt              *string   `json:"updated_at,omitempty"`
	UserId                 *int64    `json:"user_id,omitempty"`
}

Skill defines model for Skill.

type SkillFileResponse

type SkillFileResponse struct {
	Content *string `json:"content,omitempty"`
	Path    *string `json:"path,omitempty"`
}

SkillFileResponse defines model for SkillFileResponse.

type SkillList

type SkillList struct {
	Items []Skill `json:"items"`
}

SkillList defines model for SkillList.

type SkillSearchResult

type SkillSearchResult struct {
	Id       *string `json:"id,omitempty"`
	Installs *int    `json:"installs,omitempty"`
	Name     *string `json:"name,omitempty"`
	SkillId  *string `json:"skillId,omitempty"`
	Source   *string `json:"source,omitempty"`
}

SkillSearchResult defines model for SkillSearchResult.

type SkillSearchResultList

type SkillSearchResultList struct {
	Items []SkillSearchResult `json:"items"`
}

SkillSearchResultList defines model for SkillSearchResultList.

type SkillUploadResult

type SkillUploadResult struct {
	Id   *string `json:"id,omitempty"`
	Name *string `json:"name,omitempty"`
}

SkillUploadResult defines model for SkillUploadResult.

type SourceType

type SourceType string

SourceType defines model for SourceType.

const (
	Github  SourceType = "github"
	Pdf     SourceType = "pdf"
	Rss     SourceType = "rss"
	Twitter SourceType = "twitter"
	Web     SourceType = "web"
	Youtube SourceType = "youtube"
)

Defines values for SourceType.

func (SourceType) Valid

func (e SourceType) Valid() bool

Valid indicates whether the value is a known member of the SourceType enum.

type StatusDatabase added in v0.25.5

type StatusDatabase struct {
	Error     *string  `json:"error,omitempty"`
	LatencyMs *float64 `json:"latencyMs,omitempty"`
	Status    string   `json:"status"`
}

StatusDatabase defines model for StatusDatabase.

type StatusMemory added in v0.25.5

type StatusMemory struct {
	AllocBytes     int64 `json:"allocBytes"`
	HeapAllocBytes int64 `json:"heapAllocBytes"`
	NumGC          int   `json:"numGC"`
	SysBytes       int64 `json:"sysBytes"`
}

StatusMemory defines model for StatusMemory.

type StatusPlugins added in v0.25.5

type StatusPlugins struct {
	Disabled int `json:"disabled"`
	Enabled  int `json:"enabled"`
	Total    int `json:"total"`
}

StatusPlugins defines model for StatusPlugins.

type StatusResponse added in v0.25.5

type StatusResponse struct {
	BuildDate     *string         `json:"buildDate,omitempty"`
	Commit        *string         `json:"commit,omitempty"`
	Database      *StatusDatabase `json:"database,omitempty"`
	Plugins       *StatusPlugins  `json:"plugins,omitempty"`
	Runtime       *StatusRuntime  `json:"runtime,omitempty"`
	Status        string          `json:"status"`
	UptimeSeconds *int64          `json:"uptimeSeconds,omitempty"`
	Version       string          `json:"version"`
}

StatusResponse defines model for StatusResponse.

type StatusRuntime added in v0.25.5

type StatusRuntime struct {
	Arch       string       `json:"arch"`
	GoVersion  string       `json:"goVersion"`
	Goroutines int          `json:"goroutines"`
	Memory     StatusMemory `json:"memory"`
	Os         string       `json:"os"`
}

StatusRuntime defines model for StatusRuntime.

type StoredDigest added in v0.30.0

type StoredDigest struct {
	ArchivedCount        int64      `json:"archived_count"`
	CreatedAt            time.Time  `json:"created_at"`
	Date                 string     `json:"date"`
	Id                   string     `json:"id"`
	Narrative            string     `json:"narrative"`
	ReadCount            int64      `json:"read_count"`
	SavedYesterday       []Article  `json:"saved_yesterday"`
	SavedYesterdayCount  int64      `json:"saved_yesterday_count"`
	StarredCount         int64      `json:"starred_count"`
	TopTags              []TagCount `json:"top_tags"`
	TotalArticles        int64      `json:"total_articles"`
	UnreadCount          int64      `json:"unread_count"`
	UpdatedAt            time.Time  `json:"updated_at"`
	WorthRevisiting      []Article  `json:"worth_revisiting"`
	WorthRevisitingCount int64      `json:"worth_revisiting_count"`
}

StoredDigest defines model for StoredDigest.

type StoredDigestSummary added in v0.30.0

type StoredDigestSummary struct {
	CreatedAt            time.Time `json:"created_at"`
	Date                 string    `json:"date"`
	Id                   string    `json:"id"`
	Narrative            string    `json:"narrative"`
	SavedYesterdayCount  int64     `json:"saved_yesterday_count"`
	TotalArticles        int64     `json:"total_articles"`
	WorthRevisitingCount int64     `json:"worth_revisiting_count"`
}

StoredDigestSummary defines model for StoredDigestSummary.

type StoredDigestSummaryList added in v0.30.0

type StoredDigestSummaryList struct {
	Items []StoredDigestSummary `json:"items"`
	Total int64                 `json:"total"`
}

StoredDigestSummaryList defines model for StoredDigestSummaryList.

type SystemPromptResponse

type SystemPromptResponse struct {
	SystemPrompt string `json:"system_prompt"`
}

SystemPromptResponse defines model for SystemPromptResponse.

type TagCount

type TagCount struct {
	Count int64  `json:"count"`
	Tag   string `json:"tag"`
}

TagCount defines model for TagCount.

type TogglePluginRequest

type TogglePluginRequest struct {
	Enabled bool `json:"enabled"`
}

TogglePluginRequest defines model for TogglePluginRequest.

type Tool

type Tool struct {
	Category    string                  `json:"category"`
	Description string                  `json:"description"`
	InputSchema *map[string]interface{} `json:"input_schema,omitempty"`
	Name        string                  `json:"name"`
}

Tool defines model for Tool.

type TriggerJobResult

type TriggerJobResult struct {
	RunId  *string `json:"run_id,omitempty"`
	Status string  `json:"status"`
}

TriggerJobResult defines model for TriggerJobResult.

type Unauthorized

type Unauthorized struct {
	Error string `json:"error"`
}

Unauthorized defines model for Unauthorized.

type UpdateActiveRequest

type UpdateActiveRequest struct {
	IsActive bool `json:"is_active"`
}

UpdateActiveRequest defines model for UpdateActiveRequest.

type UpdateAgentsRequest

type UpdateAgentsRequest struct {
	AgentIds []string `json:"agent_ids"`
}

UpdateAgentsRequest defines model for UpdateAgentsRequest.

type UpdateArticleRequest

type UpdateArticleRequest struct {
	Author *string `json:"author,omitempty"`

	// Content If set, rewrites the markdown file body.
	Content     *string            `json:"content,omitempty"`
	FilePath    *string            `json:"file_path,omitempty"`
	Metadata    *map[string]string `json:"metadata,omitempty"`
	PublishedAt *time.Time         `json:"published_at,omitempty"`
	Starred     *bool              `json:"starred,omitempty"`
	Status      *ArticleStatus     `json:"status,omitempty"`
	Summary     *string            `json:"summary,omitempty"`
	Tags        *[]string          `json:"tags,omitempty"`
	Title       *string            `json:"title,omitempty"`
}

UpdateArticleRequest Only provided fields are updated.

type UpdateDefaultAgentRequest

type UpdateDefaultAgentRequest struct {
	DefaultAgentId string `json:"default_agent_id"`
}

UpdateDefaultAgentRequest defines model for UpdateDefaultAgentRequest.

type UpdateFeedEntryRequest

type UpdateFeedEntryRequest struct {
	ArticleId *string         `json:"article_id,omitempty"`
	ErrorMsg  *string         `json:"error_msg,omitempty"`
	Status    FeedEntryStatus `json:"status"`
}

UpdateFeedEntryRequest defines model for UpdateFeedEntryRequest.

type UpdateFeedRequest

type UpdateFeedRequest struct {
	CheckInterval *string `json:"check_interval,omitempty"`
	Description   *string `json:"description,omitempty"`
	Enabled       *bool   `json:"enabled,omitempty"`
	Title         *string `json:"title,omitempty"`
}

UpdateFeedRequest defines model for UpdateFeedRequest.

type UpdateNotifyIdentityRequest

type UpdateNotifyIdentityRequest struct {
	NotifyIdentityId *int64 `json:"notify_identity_id,omitempty"`
}

UpdateNotifyIdentityRequest defines model for UpdateNotifyIdentityRequest.

type UpdatePluginConfigRequest

type UpdatePluginConfigRequest struct {
	Config *map[string]interface{} `json:"config,omitempty"`
}

UpdatePluginConfigRequest defines model for UpdatePluginConfigRequest.

type UpdateRoleRequest

type UpdateRoleRequest struct {
	Role string `json:"role"`
}

UpdateRoleRequest defines model for UpdateRoleRequest.

type UpdateSkillRequest

type UpdateSkillRequest struct {
	Description            *string            `json:"description,omitempty"`
	DisableModelInvocation *bool              `json:"disable_model_invocation,omitempty"`
	Files                  *map[string]string `json:"files,omitempty"`
	Status                 *string            `json:"status,omitempty"`
}

UpdateSkillRequest defines model for UpdateSkillRequest.

type UserMemory

type UserMemory map[string]interface{}

UserMemory defines model for UserMemory.

type VaultEntry

type VaultEntry struct {
	CreatedAt string `json:"created_at"`
	Name      string `json:"name"`
	UpdatedAt string `json:"updated_at"`
}

VaultEntry defines model for VaultEntry.

type VaultEntryValue

type VaultEntryValue struct {
	Name  string `json:"name"`
	Value string `json:"value"`
}

VaultEntryValue defines model for VaultEntryValue.

type WeixinQRCode

type WeixinQRCode struct {
	Qrcode           *string `json:"qrcode,omitempty"`
	QrcodeImgContent *string `json:"qrcode_img_content,omitempty"`
}

WeixinQRCode defines model for WeixinQRCode.

type WeixinQRStatus

type WeixinQRStatus struct {
	Baseurl     *string `json:"baseurl,omitempty"`
	BotToken    *string `json:"bot_token,omitempty"`
	IlinkBotId  *string `json:"ilink_bot_id,omitempty"`
	IlinkUserId *string `json:"ilink_user_id,omitempty"`
	Status      *string `json:"status,omitempty"`
}

WeixinQRStatus defines model for WeixinQRStatus.

type WorkspaceCreateRequest

type WorkspaceCreateRequest struct {
	// Content Initial file content (ignored when is_dir is true)
	Content *string `json:"content,omitempty"`

	// IsDir Create a directory when true; a file when false or omitted
	IsDir *bool `json:"is_dir,omitempty"`

	// Path Relative path for the new file or directory
	Path string `json:"path"`
}

WorkspaceCreateRequest defines model for WorkspaceCreateRequest.

type WorkspaceDeleteRequest

type WorkspaceDeleteRequest struct {
	// Path Relative path of the file or directory to delete
	Path string `json:"path"`
}

WorkspaceDeleteRequest defines model for WorkspaceDeleteRequest.

type WorkspaceFileContent

type WorkspaceFileContent struct {
	// Content File text content
	Content string `json:"content"`

	// Language Detected language hint for syntax highlighting
	Language *string `json:"language,omitempty"`

	// Path Relative path of the file within the workspace
	Path string `json:"path"`
}

WorkspaceFileContent defines model for WorkspaceFileContent.

type WorkspaceMoveRequest

type WorkspaceMoveRequest struct {
	// NewPath New relative path (rename or move destination)
	NewPath string `json:"new_path"`

	// Path Current relative path
	Path string `json:"path"`
}

WorkspaceMoveRequest defines model for WorkspaceMoveRequest.

type WorkspaceUpdateContentRequest

type WorkspaceUpdateContentRequest struct {
	// Content New file content to write
	Content string `json:"content"`

	// Path Relative path of the file within the workspace
	Path string `json:"path"`
}

WorkspaceUpdateContentRequest defines model for WorkspaceUpdateContentRequest.

type WorkspaceUploadResponse

type WorkspaceUploadResponse struct {
	// Path Relative path of the uploaded file within the workspace
	Path string `json:"path"`
}

WorkspaceUploadResponse defines model for WorkspaceUploadResponse.

Jump to